#ifndef GLOBAL
#define GLOBAL

#include <random>

// TODO: check if we omp is needed beyond drive.cpp
#ifdef _OPENMP
#include <omp.h>
#endif

#include <RcppArmadillo.h>


#endif
